@@ -5,7 +5,7 @@
 #ifdef WIN32
 #include <windows.h>
 #ifndef __GNUC__
-#pragma comment(lib, "libmysql.lib")
+#pragma comment(lib, "mysqlclient.lib")
 #endif
 #include <mysql.h>
 #include <mysqld_error.h>
