@@ -14,7 +14,7 @@
 
 #include "../helper/message-display.h"
 #include "../helper/printing.h"
-#include "../helper/string.h"
+#include "../libgammu/misc/string.h"
 
 void BackupSMS(int argc UNUSED, char *argv[])
 {
