@@ -85,55 +85,55 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_DEVICEOPENERROR, "DEVICEOPENERROR",		N_("Error opening device. Unknown, busy or no permissions.")},
 	{ERR_DEVICELOCKED, "DEVICELOCKED",		N_("Error opening device, it is locked.")},
 	{ERR_DEVICENOTEXIST, "DEVICENOTEXIST",		N_("Error opening device, it doesn't exist.")},
-	{ERR_DEVICEBUSY, "DEVICEBUSY",		N_("Error opening device, it is already opened by other application.")},
-	{ERR_DEVICENOPERMISSION, "DEVICENOPERMISSION",	N_("Error opening device, you don't have permissions.")},
+	{ERR_DEVICEBUSY, "DEVICEBUSY",		N_("Error opening device, it is already opened by another app.")},
+	{ERR_DEVICENOPERMISSION, "DEVICENOPERMISSION",	N_("Error opening device, you don't have the required permission.")},
 	{ERR_DEVICENODRIVER, "DEVICENODRIVER",		N_("Error opening device. No required driver in operating system.")},
 	{ERR_DEVICENOTWORK, "DEVICENOTWORK",		N_("Error opening device. Some hardware not connected/wrongly configured.")},
 	{ERR_DEVICEDTRRTSERROR, "DEVICEDTRRTSERROR",		N_("Error setting device DTR or RTS.")},
-	{ERR_DEVICECHANGESPEEDERROR, "DEVICECHANGESPEEDERROR",	N_("Error setting device speed. Maybe speed not supported.")},
+	{ERR_DEVICECHANGESPEEDERROR, "DEVICECHANGESPEEDERROR",	N_("Error setting device speed. Maybe the speed is not supported?")},
 	{ERR_DEVICEWRITEERROR, "DEVICEWRITEERROR",		N_("Error writing to the device.")},
 	{ERR_DEVICEREADERROR, "DEVICEREADERROR",		N_("Error during reading from the device.")},
 	{ERR_DEVICEPARITYERROR, "DEVICEPARITYERROR",		N_("Can't set parity on the device.")},
-	{ERR_TIMEOUT, "TIMEOUT",			N_("No response in specified timeout. Probably phone not connected.")},
-	{ERR_FRAMENOTREQUESTED, "FRAMENOTREQUESTED",		N_("Frame not requested right now. See <https://wammu.eu/support/bugs/> for information how to report it.")},
-	{ERR_UNKNOWNRESPONSE, "UNKNOWNRESPONSE",		N_("Unknown response from phone. See <https://wammu.eu/support/bugs/> for information how to report it.")},
-	{ERR_UNKNOWNFRAME, "UNKNOWNFRAME",		N_("Unknown frame. See <https://wammu.eu/support/bugs/> for information how to report it.")},
+	{ERR_TIMEOUT, "TIMEOUT",			N_("No response in specified timeout. Probably the phone is not connected.")},
+	{ERR_FRAMENOTREQUESTED, "FRAMENOTREQUESTED",		N_("Frame not requested right now. See <https://wammu.eu/support/bugs/> for information on how to report it.")},
+	{ERR_UNKNOWNRESPONSE, "UNKNOWNRESPONSE",		N_("Unknown response from phone. See <https://wammu.eu/support/bugs/> for information on how to report it.")},
+	{ERR_UNKNOWNFRAME, "UNKNOWNFRAME",		N_("Unknown frame. See <https://wammu.eu/support/bugs/> for information on how to report it.")},
 	{ERR_UNKNOWNCONNECTIONTYPESTRING, "UNKNOWNCONNECTIONTYPESTRING",N_("Unknown connection type string. Check config file.")},
 	{ERR_UNKNOWNMODELSTRING, "UNKNOWNMODELSTRING",	N_("Unknown model type string. Check config file.")},
-	{ERR_SOURCENOTAVAILABLE, "SOURCENOTAVAILABLE",	N_("Some functions not available for your system (disabled in config or not implemented).")},
+	{ERR_SOURCENOTAVAILABLE, "SOURCENOTAVAILABLE",	N_("Some functions are not available for your system (disabled in config or not implemented).")},
 	{ERR_NOTSUPPORTED, "NOTSUPPORTED",		N_("Function not supported by phone.")},
-	{ERR_EMPTY, "EMPTY",			N_("Entry is empty.")},
+	{ERR_EMPTY, "EMPTY",			N_("Empty entry.")},
 	{ERR_SECURITYERROR, "SECURITYERROR",		N_("Security error. Maybe no PIN?")},
 	{ERR_INVALIDLOCATION, "INVALIDLOCATION",		N_("Invalid location. Maybe too high?")},
-	{ERR_NOTIMPLEMENTED, "NOTIMPLEMENTED",		N_("Functionality not implemented. You are welcome to help authors with it.")},
+	{ERR_NOTIMPLEMENTED, "NOTIMPLEMENTED",		N_("Functionality not implemented. You are welcome to help.")},
 	{ERR_FULL, "FULL",			N_("Memory full.")},
 	{ERR_UNKNOWN, "UNKNOWN",			N_("Unknown error.")},
 	{ERR_CANTOPENFILE, "CANTOPENFILE",		N_("Can not open specified file.")},
-	{ERR_MOREMEMORY, "MOREMEMORY",		N_("More memory required...")},
+	{ERR_MOREMEMORY, "MOREMEMORY",		N_("More memory required…")},
 	{ERR_PERMISSION, "PERMISSION",		N_("Operation not allowed by phone.")},
-	{ERR_EMPTYSMSC, "EMPTYSMSC",			N_("No SMSC number given. Provide it manually or use the one configured in phone.")},
-	{ERR_INSIDEPHONEMENU, "INSIDEPHONEMENU",		N_("You're inside phone menu (maybe editing?). Leave it and try again.")},
-	{ERR_NOTCONNECTED, "NOTCONNECTED",		N_("Phone is not connected.")},
+	{ERR_EMPTYSMSC, "EMPTYSMSC",			N_("No SMSC number given. Provide it manually or use the one configured on the phone.")},
+	{ERR_INSIDEPHONEMENU, "INSIDEPHONEMENU",		N_("You're inside the phone menu (maybe editing?). Exit it and try again.")},
+	{ERR_NOTCONNECTED, "NOTCONNECTED",		N_("Phone not connected.")},
 	{ERR_WORKINPROGRESS, "WORKINPROGRESS",		N_("Function is currently being implemented. If you want to help, please contact authors.")},
-	{ERR_PHONEOFF, "PHONEOFF",			N_("Phone is disabled and connected to charger.")},
+	{ERR_PHONEOFF, "PHONEOFF",			N_("Phone disabled and connected to charger.")},
 	{ERR_FILENOTSUPPORTED, "FILENOTSUPPORTED",		N_("File format not supported by Gammu.")},
 	{ERR_BUG, "BUG",			N_("Nobody is perfect, some bug appeared in protocol implementation. Please contact authors.")},
-	{ERR_CANCELED, "CANCELED",			N_("Transfer was canceled by phone, maybe you pressed cancel on phone.")},
+	{ERR_CANCELED, "CANCELED",			N_("Transfer canceled by phone, maybe you pressed \"Cancel\" on the phone.")},
 	{ERR_NEEDANOTHERANSWER, "NEEDANOTHERANSWER",		N_("Phone module need to send another answer frame.")}, /* This should be only internal. */
 	{ERR_OTHERCONNECTIONREQUIRED, "OTHERCONNECTIONREQUIRED",	N_("Current connection type doesn't support called function.")},
 	{ERR_WRONGCRC, "WRONGCRC",			N_("CRC error.")},
 	{ERR_INVALIDDATETIME, "INVALIDDATETIME",		N_("Invalid date or time specified.")},
-	{ERR_MEMORY, "MEMORY",			N_("Phone memory error, maybe it is read only.")},
+	{ERR_MEMORY, "MEMORY",			N_("Phone memory error, maybe it is read only?")},
 	{ERR_INVALIDDATA, "INVALIDDATA",		N_("Invalid data given to phone.")},
 	{ERR_FILEALREADYEXIST, "FILEALREADYEXIST",		N_("File with specified name already exists.")},
 	{ERR_FILENOTEXIST, "FILENOTEXIST",		N_("File with specified name doesn't exist.")},
-	{ERR_SHOULDBEFOLDER, "SHOULDBEFOLDER",		N_("You have to give folder name and not file name.")},
-	{ERR_SHOULDBEFILE, "SHOULDBEFILE",		N_("You have to give file name and not folder name.")},
+	{ERR_SHOULDBEFOLDER, "SHOULDBEFOLDER",		N_("You have to supply folder name and not filename.")},
+	{ERR_SHOULDBEFILE, "SHOULDBEFILE",		N_("You have to supply filename and not folder name.")},
 	{ERR_NOSIM, "NOSIM",			N_("Can not access SIM card.")},
-	{ERR_GNAPPLETWRONG, "GNAPPLETWRONG",		N_("Wrong GNAPPLET version in phone. Use version from currently used Gammu.")},
+	{ERR_GNAPPLETWRONG, "GNAPPLETWRONG",		N_("Wrong GNAPPLET version in use on phone. Use version from currently used Gammu.")},
 	{ERR_FOLDERPART, "FOLDERPART",		N_("Only part of folder has been listed.")},
 	{ERR_FOLDERNOTEMPTY, "FOLDERNOTEMPTY",		N_("Folder must be empty.")},
-	{ERR_DATACONVERTED, "DATACONVERTED",		N_("Data were converted.")},
+	{ERR_DATACONVERTED, "DATACONVERTED",		N_("Data converted.")},
 	{ERR_UNCONFIGURED, "UNCONFIGURED",		N_("Gammu is not configured.")},
 	{ERR_WRONGFOLDER, "WRONGFOLDER",		N_("Wrong folder used.")},
 	{ERR_PHONE_INTERNAL, "PHONE_INTERNAL",		N_("Internal phone error.")},
@@ -160,6 +160,8 @@ static PrintErrorEntry PrintErrorEntries[] = {
 	{ERR_DB_CONNECT, "DB_CONNECT", N_("Failed to connect to database.")},
 	{ERR_DB_TIMEOUT, "DB_TIMEOUT", N_("Database connection timeout.")},
 	{ERR_SQL, "SQL", N_("Error in executing SQL query.")},
+	{ERR_MEMORY_NOT_AVAILABLE, "MEMORY_NOT_AVAILABLE", N_("The type of memory is not available or has been disabled.")},
+	{ERR_INVALID_OPERATION, "INVALID_OPERATION", N_("The operation cannot be performed.")},
 
 	{0,	"",				""}
 };
