@@ -462,13 +462,13 @@ GSM_Error SAMSUNG_CheckCalendar(GSM_StateMachine *s)
 
 	smprintf(s, "Checking for supported calendar commands\n");
 
-	ATGEN_WaitForAutoLen(s, "AT+SSHT?\r", 0x00, 10, ID_GetProtocol);
+	error = ATGEN_WaitForAutoLen(s, "AT+SSHT?\r", 0x00, 10, ID_GetProtocol);
 	if (error == ERR_NONE) {
 		Priv->SamsungCalendar = SAMSUNG_SSH;
 		return ERR_NONE;
 	}
 
-	ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetProtocol);
+	error = ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetProtocol);
 	if (error == ERR_NONE) {
 		Priv->SamsungCalendar = SAMSUNG_ORG;
 		return ERR_NONE;
@@ -810,10 +810,10 @@ GSM_Error SAMSUNG_GetCalendarStatus(GSM_StateMachine *s, GSM_CalendarStatus *Sta
 	if (Priv->SamsungCalendar == SAMSUNG_NONE) {
 		return ERR_NOTSUPPORTED;
 	} else if (Priv->SamsungCalendar == SAMSUNG_SSH) {
-		ATGEN_WaitForAutoLen(s, "AT+SSHI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
+		error = ATGEN_WaitForAutoLen(s, "AT+SSHI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
 		return error;
 	} else if (Priv->SamsungCalendar == SAMSUNG_ORG) {
-		ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
+		error = ATGEN_WaitForAutoLen(s, "AT+ORGI?\r", 0x00, 10, ID_GetCalendarNotesInfo);
 		return error;
 	}
 
@@ -1094,7 +1094,7 @@ GSM_Error SAMSUNG_GetNextCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note,
 	}
 
 	if (start) {
-		/* One bellow actual first position */
+		/* One below actual first position */
 		Note->Location = 0;
 		error = SAMSUNG_GetCalendarStatus(s, &Priv->CalendarStatus);
 		if (error != ERR_NONE) {
@@ -1145,7 +1145,7 @@ GSM_Error SAMSUNG_GetCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 		return ERR_BUG;
 	}
 
-	ATGEN_WaitFor(s, req, len, 0x00, 10, ID_GetCalendarNote);
+	error = ATGEN_WaitFor(s, req, len, 0x00, 10, ID_GetCalendarNote);
 	return error;
 }
 
@@ -1173,7 +1173,7 @@ GSM_Error SAMSUNG_DelCalendar(GSM_StateMachine *s, GSM_CalendarEntry *Note)
 		return ERR_BUG;
 	}
 
-	ATGEN_WaitFor(s, req, len, 0x00, 10, ID_DeleteCalendarNote);
+	error = ATGEN_WaitFor(s, req, len, 0x00, 10, ID_DeleteCalendarNote);
 	return error;
 }
 
