@@ -2,8 +2,8 @@
  * Windows event log logging backend.
  */
 
-#ifndef __smsd_common_h__
-#define __smsd_common_h__
+#ifndef __smsd_log_event_h__
+#define __smsd_log_event_h__
 
 /**
  * Initalizes logging to Windows event log.
@@ -20,4 +20,14 @@ void eventlog_log(void *handle, int level, const char *message);
  */
 void eventlog_close(void *handle);
 
+/**
+ * Registers event log handler.
+ */
+gboolean eventlog_register(void);
+
+/**
+ * Deregisters event log handler.
+ */
+gboolean eventlog_deregister(void);
+
 #endif
