@@ -157,7 +157,7 @@ const char input[] =
     "133 - FORTUNE DISCUSSES THE DIFFERENCES BETWEEN MEN AND WOMEN:	#8\n"
     "134 - The all-softening overpowering knell,\n"
     "135 - Carperpetuation (kar' pur pet u a shun), n.:\n"
-    "136 - It matters not whether you win or lose; what matters is whether II win or lose.\n"
+    "136 - It matters not whether you win or lose; what matters is whether I win or lose.\n"
     "137 - Fascinating, a totally parochial attitude.\n"
     "138 - I am convinced that the truest act of courage is to sacrifice ourselves\n"
     "139 - Q:	How many journalists does it take to screw in a light bulb?\n"
@@ -348,7 +348,7 @@ const char input[] =
     "324 - Just don't create a file called -rf.  :-)\n"
     "325 - Being a BALD HERO is almost as FESTIVE as a TATTOOED KNOCKWURST.\n"
     "326 - Not everything worth doing is worth doing well.\n"
-    "327 - Calm down, it's *____only* ones and zeroes.\n"
+    "327 - Calm down, it's *only* ones and zeroes.\n"
     "328 - Delay not, Caesar.  Read it instantly.\n"
     "329 - If science were explained to the average person in a way that is accessible\n"
     "330 - <Midgar> From all the sterotypes about Aussies, I figure you guys are\n"
